Documentation
¶
Overview ¶
Package info contains service discovery features.
These were separated out into a separate package to prevent import loops.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Feature ¶
type Feature struct {
XMLName xml.Name `xml:"http://jabber.org/protocol/disco#info feature"`
Var string `xml:"var,attr"`
}
Feature represents a feature supported by an entity on the network.
func (Feature) MarshalXML ¶
MarshalXML implements xml.Marshaler.
func (Feature) TokenReader ¶
func (f Feature) TokenReader() xml.TokenReader
TokenReader implements xmlstream.Marshaler.
type FeatureIter ¶
FeatureIter is the interface implemented by types that implement disco features.
type Identity ¶
type Identity struct {
XMLName xml.Name `xml:"http://jabber.org/protocol/disco#info identity"`
Category string `xml:"category,attr"`
Type string `xml:"type,attr"`
Name string `xml:"name,attr,omitempty"`
Lang string `xml:"http://www.w3.org/XML/1998/namespace lang,attr,omitempty"`
}
Identity is the type and category of a node on the network. Normally one of the pre-defined Identity types should be used.
func (Identity) MarshalXML ¶
MarshalXML implements xml.Marshaler.
func (Identity) TokenReader ¶
func (i Identity) TokenReader() xml.TokenReader
TokenReader implements xmlstream.Marshaler.
Click to show internal directories.
Click to hide internal directories.